import os
import csv

def convert_size(size_bytes):
    # Size thresholds for conversion
    KB = 1024
    MB = KB * 1024
    
    if size_bytes < KB:
        return "%d B" % size_bytes
    elif size_bytes < MB:
        return "%.2f KB" % (size_bytes / KB)
    else:
        return "%.2f MB" % (size_bytes / MB)

def find_files(directory, csv_file):
    with open(csv_file, 'w', newline='', encoding='utf-8') as csvfile:
        csv_writer = csv.writer(csvfile, delimiter=',')
        csv_writer.writerow(['Folder', 'File Name', 'Size'])
        
        for root, dirs, files in os.walk(directory):
            # Exclude certain folders
            if 'zoomify' in dirs:
                dirs.remove('zoomify')
            if 'thumbnails' in dirs:
                dirs.remove('thumbnails')

            for file in files:
                file_path = os.path.join(root, file)
                # Compute relative path
                relative_path = os.path.relpath(root, directory)
                # Encode the path with 'replace' error handling
                encoded_path = relative_path.encode('utf-8', errors='replace')
                # Decode the encoded path to a string
                decoded_path = encoded_path.decode('utf-8')
                
                # Encode the file name with 'replace' error handling
                encoded_file_name = file.encode('utf-8', errors='replace')
                # Decode the encoded file name to a string
                decoded_file_name = encoded_file_name.decode('utf-8')
                
                # Get file size
                size = os.path.getsize(file_path)
                # Convert size to human-readable format
                formatted_size = convert_size(size)
                csv_writer.writerow([decoded_path, decoded_file_name, formatted_size])

# Starting from the current directory
current_directory = os.getcwd()
output_csv_file = 'file_list.csv'
find_files(current_directory, output_csv_file)
print("CSV file generated successfully:", output_csv_file)

